@@ -1,8 +1,10 @@
 import unittest
-from enum import unique, auto
+from enum import Enum, unique, auto
+import pandas as pd
+import numpy as np
+import datetime
 
-from helpsk.pandas import *
-from helpsk.pandas_style import html_escape_dataframe
+import helpsk.pandas_style as hps
 from helpsk.utility import suppress_warnings
 from helpsk.validation import dataframes_match
 from tests.helpers import get_data_credit, get_test_path, clean_formatted_dataframe
@@ -19,29 +21,30 @@ class TestPandasStyle(unittest.TestCase):
     @classmethod
     def setUpClass(cls):
         cls.credit_data = get_data_credit()
-        sample_data = pd.DataFrame({'col_a': [np.nan, 2, 3, 4],
-                                    'col_b': [np.nan, 'b', 'd', 'd'],
-                                    'col_c': pd.date_range('2021-01-01', '2021-01-04'),
-                                    'col_d': [None, np.nan,
-                                              datetime.date(2021, 4, 2), datetime.date(2021, 4, 2)],
-                                    'col_e': np.nan,
-                                    'col_f': [1.0, 2.0, 3.0, 4.0],
-                                    'col_h': [np.nan, TestEnum.VALUE_A, TestEnum.VALUE_B, TestEnum.VALUE_B],
-                                    'col_i': [None, np.nan, datetime.datetime(2021, 4, 2, 0, 0, 0),
-                                              datetime.datetime(2021, 4, 2, 0, 0, 0)],
-                                    })
+        sample_data = pd.DataFrame({
+            'col_a': [np.nan, 2, 3, 4],
+            'col_b': [np.nan, 'b', 'd', 'd'],
+            'col_c': pd.date_range('2021-01-01', '2021-01-04'),
+            'col_d': [None, np.nan, datetime.date(2021, 4, 2), datetime.date(2021, 4, 2)],
+            'col_e': np.nan,
+            'col_f': [1.0, 2.0, 3.0, 4.0],
+            'col_h': [np.nan, TestEnum.VALUE_A, TestEnum.VALUE_B, TestEnum.VALUE_B],
+            'col_i': [
+                None, np.nan, datetime.datetime(2021, 4, 2, 0, 0, 0), datetime.datetime(2021, 4, 2, 0, 0, 0)
+            ],
+        })
         sample_data.loc[0, 'col_c'] = np.nan
         sample_data['col_g'] = sample_data['col_b'].astype('category')
         cls.sample_data = sample_data
 
     def test_format(self):
-        with open(get_test_path() + '/test_files/pandas_style/format__default.html', 'w') as file:
-            file.write(clean_formatted_dataframe(pstyle.format(self.sample_data).render()))
+        with open(get_test_path('pandas_style/format__default.html'), 'w') as file:
+            file.write(clean_formatted_dataframe(hps.format(self.sample_data).to_html()))
 
     def test_background_color(self):
         with suppress_warnings():
-            with open(get_test_path() + '/test_files/pandas_style/background_color__default.html', 'w') as file:
-                file.write(clean_formatted_dataframe(pstyle.background_color(self.sample_data).render()))
+            with open(get_test_path('pandas_style/background_color__default.html'), 'w') as file:
+                file.write(clean_formatted_dataframe(hps.background_color(self.sample_data).to_html()))
 
     def test_bar_inverse(self):
         # found a bug when doing `value_frequency(series, sort_by_frequency=False)` with a series that had
@@ -54,13 +57,13 @@ class TestPandasStyle(unittest.TestCase):
                          column='bar_inverse',
                          value=test_data['col_f'].copy())
 
-        with open(get_test_path() + '/test_files/pandas_style/inverse_bar.html', 'w') as file:
+        with open(get_test_path('pandas_style/inverse_bar.html'), 'w') as file:
             table_html = test_data.style. \
                 bar(subset=['col_a'], color='pink', vmin=2). \
-                pipe(pstyle.bar_inverse, subset='col_a_copy', color='pink', min_value=2). \
+                pipe(hps.bar_inverse, subset='col_a_copy', color='pink', min_value=2). \
                 bar(subset=['col_f'], color='green'). \
-                pipe(pstyle.bar_inverse, subset='bar_inverse', color='green'). \
-                render()
+                pipe(hps.bar_inverse, subset='bar_inverse', color='green'). \
+                to_html()
 
             file.write(clean_formatted_dataframe(table_html))
 
@@ -72,12 +75,12 @@ class TestPandasStyle(unittest.TestCase):
         test_data.insert(loc=5,
                          column='credit_amount_copy',
                          value=test_data['credit_amount'].copy())
-        with open(get_test_path() + '/test_files/pandas_style/all_styles.html', 'w') as file:
+        with open(get_test_path('pandas_style/all_styles.html'), 'w') as file:
             table_html = test_data. \
                 head(20). \
-                pipe(pstyle.bar_inverse, subset='credit_amount_copy', color='gray'). \
+                pipe(hps.bar_inverse, subset='credit_amount_copy', color='gray'). \
                 bar(subset=['credit_amount'], color='grey'). \
-                render()
+                to_html()
             file.write(clean_formatted_dataframe(table_html))
 
     def test_html_escape_dataframe(self):
@@ -94,7 +97,7 @@ class TestPandasStyle(unittest.TestCase):
             '&lt;C&gt;': [np.nan, np.nan, '&lt;asdf&gt;']
         }, index=['&lt;1&gt;', '2', '&lt;3&gt;'])
         expected_dataframe['&lt;C&gt;'] = expected_dataframe['&lt;C&gt;'].astype('category')
-        self.assertTrue(dataframes_match([html_escape_dataframe(dataframe), expected_dataframe]))
+        self.assertTrue(dataframes_match([hps.html_escape_dataframe(dataframe), expected_dataframe]))
 
         # multi-index
         dataframe = pd.DataFrame({
@@ -114,4 +117,8 @@ class TestPandasStyle(unittest.TestCase):
                                             ('2', '&lt;y&gt;'),
                                             ('&lt;3&gt;', 'z')]))
         expected_dataframe['&lt;C&gt;'] = expected_dataframe['&lt;C&gt;'].astype('category')
-        self.assertTrue(dataframes_match([html_escape_dataframe(dataframe), expected_dataframe]))
+        self.assertTrue(dataframes_match([hps.html_escape_dataframe(dataframe), expected_dataframe]))
+
+
+if __name__ == '__main__':
+    unittest.main()
